@@ -248,7 +248,10 @@ gdict_window_lookup_start_cb (GdictContext *context,
     return;
 
   if (!window->busy_cursor)
-    window->busy_cursor = gdk_cursor_new (GDK_WATCH);
+    {
+      GdkDisplay *display = gtk_widget_get_display (GTK_WIDGET (window));
+      window->busy_cursor = gdk_cursor_new_for_display (display, GDK_WATCH);
+    }
 
   message = g_strdup_printf (_("Searching for '%s'..."), window->word);
   
@@ -910,8 +913,8 @@ gdict_window_cmd_save_as (GSimpleAction   *action,
   dialog = gtk_file_chooser_dialog_new (_("Save a Copy"),
   					GTK_WINDOW (window),
   					GTK_FILE_CHOOSER_ACTION_SAVE,
-  					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-  					GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+                                        _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                        _("_Save"), GTK_RESPONSE_ACCEPT,
   					NULL);
   gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
   
@@ -1597,8 +1600,6 @@ gdict_window_constructor (GType                  type,
   /* recover the state */
   gdict_window_load_state (window);
 
-  gtk_widget_push_composite_child ();
- 
   window->main_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_add (GTK_CONTAINER (window), window->main_box);
   gtk_widget_show (window->main_box);
@@ -1833,8 +1834,6 @@ gdict_window_constructor (GType                  type,
 
   gtk_widget_grab_focus (window->entry);
 
-  gtk_widget_pop_composite_child ();
-
   window->in_construction = FALSE;
 
   return object;
